@@ -192,7 +192,13 @@ void read_arch_specific_packages (const char *buffer_p, const unsigned long buff
       j = strlen (line) - l;
       architectures = xmalloc (j + 1);
       while (k < j && line[l] != '#')
-	architectures[k++] = line[l++];
+	if (line[l] == '\t')
+	  {
+	    architectures[k++] = ' ';
+	    l++;
+	  }
+	else
+	    architectures[k++] = line[l++];
       architectures[k] = '\0';
       debug(debug_as, "architectures are \"%s\"", architectures);
 
@@ -202,9 +208,17 @@ void read_arch_specific_packages (const char *buffer_p, const unsigned long buff
 	{
 	  /* "!arch" is exclusionary; if there's a !something, but
 	     not !arch there is support for arch */
-	  if (strstr (architectures, packages_architecture) != NULL)
+	  char *w;
+	  char *p;
+
+	  for (w = p = architectures ; *w ; w++ )
+	    if (*w != '!')
+	      *p++ = *w;
+	  *p = '\0';
+
+	  if (in_arch_list(architectures, packages_architecture))
 	    {
-	      debug (debug_as, "read_arch_specficic_packages: %s doesn't need compiled on %s",
+	      debug (debug_as, "read_arch_specific_packages: %s doesn't need compiled on %s [exc]",
 		     package_name, packages_architecture);
 	      arch_specific_packages_ht_add(package_name);
 	    }
@@ -213,13 +227,13 @@ void read_arch_specific_packages (const char *buffer_p, const unsigned long buff
 	{
 	  /* "arch" is inclusionary; if arch is not listed, it's not
 	     supported by the package */
-	  if (strstr (architectures, binary_architecture_match) != NULL)
+	  if (in_arch_list (architectures, packages_architecture))
 	    debug (debug_as, "read_arch_specficic_packages: %s has %s support",
-		   package_name, binary_architecture_match);
+		   package_name, packages_architecture);
 	  else
 	    {
-	      debug (debug_as, "read_arch_specficic_packages: %s doesn't need compiled on %s",
-		     package_name, binary_architecture_match);
+	      debug (debug_as, "read_arch_specficic_packages: %s doesn't need compiled on %s [inc]",
+		     package_name, packages_architecture);
 	      arch_specific_packages_ht_add(package_name);
 	    }
 	}
