@@ -1,5 +1,5 @@
 /* Quinn Diff, Determine which packages need recompiled for any given architecture */
-/* Copyright (C) 1997-1999, James Troup <james@nocrew.org> */
+/* Copyright (C) 1997-2001, James Troup <james@nocrew.org> */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,16 +17,17 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <stdarg.h>
 #include <string.h>
 #include <errno.h>
-#include "common.h"
+#include "globals.h"
 #include "error.h"
 
 void
 debug (const int which, const char *fmt,...)
 {
-  
+
   va_list args;
 
   if (!(which & debug_level))
@@ -42,7 +43,7 @@ debug (const int which, const char *fmt,...)
 void
 debug_help (void)
 {
-  
+
   printf ("Quinn Diff debugging option, --debug=<octal value> or -D<octal value>:\n\
   number  description\n\
        1  General warnings\n\
@@ -70,8 +71,8 @@ error (const char *fmt,...)
   putc ('\n', stderr);
 }
 
-void 
-fubar (unsigned short flag, const char *fmt,...) 
+void
+fubar (unsigned short flag, const char *fmt,...)
 {
 
   unsigned short syserr = flag & SYSERR;
