@@ -23,9 +23,6 @@ GLOBAL unsigned long debug_level;
 /* The secondary architecture's name */
 GLOBAL char *packages_architecture;
 
-/* As above with a space prepended for matching */
-GLOBAL char *binary_architecture_match;
-
 /* The filename for the Packages-arch-specific file */
 GLOBAL char *packages_arch_specific_filename;
 
